@@ -7,7 +7,7 @@
 #'  location accessible via attr(sgdf@data@values, 'scaled:center') if anomalies
 #'  were computed
 #'  
-#' @importFrom raster brick mask aggregate crop scale
+#' @importFrom raster brick mask aggregate crop scale extract
 #' @importFrom SDMTools aspect slope
 #' 
 #' @param sgdf SpatialGridDataFrame containing data to extract
@@ -16,7 +16,8 @@
 #' temporal standard deviation at each location), or spatially standardized
 #' data (data minus overall spatial average divided by spatial std. dev.; each
 #' year gets its own spatial standardization )
-#' @param extent raster::extent object featuring region to extract
+#' @param extent raster::extent object featuring region to extract, or a 
+#' SpatialPolygonsXXX object used for extracting areal data
 #' @param aggfact if provided, will spatially average the data
 #' @param mask if an sgdf is provided, the data will be masked before
 #'  extraction, aggregation, and anomaly computation
@@ -43,52 +44,82 @@ extractRegion = function(sgdf, extent,
   if(!is.null(mask))
     sgdf = mask(sgdf, brick(mask))
 
-  # extract and aggregate the data
-  if(!is.null(aggfact) && aggfact > 1)
-    sgdf = aggregate(sgdf, fact=aggfact)
-  
-  if(aspect) {
-    for(i in 1:sgdf@data@nlayers) {
-      # compute aspects
-      sgdf[[i]] = aspect(sgdf[[i]], latlon = T)
-      # classify aspects
-      if(!is.null(aspect.categories)) {
-        sgdf[[i]]@data@values = as.numeric(
+  # extract data
+  if(inherits(extent,'Extent')) {
+    
+    # extract and aggregate the data
+    if(!is.null(aggfact) && aggfact > 1)
+      sgdf = aggregate(sgdf, fact=aggfact)
+    
+    if(aspect) {
+      for(i in 1:sgdf@data@nlayers) {
+        # compute aspects
+        sgdf[[i]] = aspect(sgdf[[i]], latlon = T)
+        # classify aspects
+        if(!is.null(aspect.categories)) {
+          sgdf[[i]]@data@values = as.numeric(
             cut((sgdf[[i]]@data@values + 180/aspect.categories) %% 360, 
                 seq(0, 360, length.out = aspect.categories+1))
           )
+        }
+      }
+    } else if(slope) {
+      for(i in 1:sgdf@data@nlayers) {
+        # compute slopes
+        sgdf[[i]] = slope(sgdf[[i]], latlon = T)
       }
     }
-  } else if(slope) {
-    for(i in 1:sgdf@data@nlayers) {
-      # compute slopes
-      sgdf[[i]] = slope(sgdf[[i]], latlon = T)
-    }
+    
+    # crop data
+    sgdf = raster::crop(sgdf, extent)
+    
+    # extract data to compute anomalies
+    dat = sgdf@data@values
+    
+  } else if(startsWith(class(extent), 'SpatialPolygons')) {
+    
+    # extract average value from each region
+    sgdf = raster::extract(x = sgdf, y = extent, fun = mean, sp = TRUE,
+                           na.rm = TRUE)
+    
+    # only retain the extracted data
+    sgdf@data = sgdf@data[,-(1:ncol(extent@data))]
+    
+    # extract data to compute anomalies
+    dat = sgdf@data
+    
   }
   
-  # crop data
-  sgdf = raster::crop(sgdf, extent)
+  #
+  # compute anomalies
+  #
   
   # compute anomalies
   match.opts = c('response', 'std.anomaly', 'anomaly', 'spatial.anomaly', 
                  'spatial.std.anomaly')
   type = match.opts[pmatch(type, match.opts)]
   if( type=='std.anomaly' ) {
-    sgdf@data@values = t(scale(t(sgdf@data@values), center=T, scale=T))
+    dat = t(scale(t(dat), center=T, scale=T))
   }
   else if( type=='anomaly') {
-    sgdf@data@values = t(scale(t(sgdf@data@values), center=T, scale=F))
+    dat = t(scale(t(dat), center=T, scale=F))
   }
   else if( type=='spatial.anomaly') {
-    sgdf@data@values = scale(sgdf@data@values, center=T, scale=F)
+    dat = scale(dat, center=T, scale=F)
   }
   else if( type=='spatial.std.anomaly') {
-    sgdf@data@values = scale(sgdf@data@values, center=T, scale=T)
+    dat = scale(dat, center=T, scale=T)
   }
   
-  # restore matrix structure to data
-  if(class(sgdf@data@values)!='matrix') {
-    sgdf@data@values = matrix(sgdf@data@values, ncol=1)
+  # reassemble data
+  if(inherits(extent,'Extent')) { 
+    # restore matrix structure to data
+    if(!inherits(dat,'matrix')) {
+      dat = matrix(dat, ncol=1)
+    }
+    sgdf@data@values = dat
+  } else if(startsWith(class(extent), 'SpatialPolygons')) {
+    sgdf@data = data.frame(dat)
   }
   
   sgdf
